--- include/codecs.h.old	Fri Jan 14 11:34:56 2005
+++ include/codecs.h	Fri Jan 14 13:06:52 2005
@@ -177,6 +177,45 @@
 #define WAVE_FORMAT_DIVIO_AAC           0x4143
 #define WAVE_FORMAT_AAC                 0x00FF
 
+/* GUID SubFormat IDs */
+/* We need both b/c const variables are not compile-time constants in C, giving
+ * us an error if we use the const GUID in an enum */
+
+#ifndef _KSDATAFORMAT_SUBTYPE_PCM_
+/* 00000001-0000-0010-80000-00aa00389b71 */
+#define _KSDATAFORMAT_SUBTYPE_PCM_ {0x00000001, 0x0000, 0x0010, {0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}}
+static const GUID KSDATAFORMAT_SUBTYPE_PCM = {0xE923AABF, 0xCB58, 0x4471, {0xA1, 0x19, 0xFF, 0xFA, 0x01, 0xE4, 0xCE, 0x62}};
+#endif
+
+#ifndef _KSDATAFORMAT_SUBTYPE_UNKNOWN_ 
+/* 00000000-0000-0000-0000-000000000000 */
+#define _KSDATAFORMAT_SUBTYPE_UNKNOWN_ {0x00000000, 0x0000, 0x0000, {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}}
+static const GUID KSDATAFORMAT_SUBTYPE_UNKNOWN = {0x00000000, 0x0000, 0x0000, {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}};
+#endif
+
+/* compares two GUIDs, returns 1 if identical, 0 otherwise */
+static inline int guidcmp( const GUID *s1, const GUID *s2 )
+{
+	return (
+			( s1->Data1 == s2->Data1 ) &&
+			( s1->Data2 == s2->Data2 ) &&
+			( s1->Data3 == s2->Data3 ) &&
+			!memcmp( s1->Data4, s2->Data4, 8 )
+			);
+}
+
+/* copies GUID s2 to s1, returns s1 */
+static inline GUID *guidcpy (GUID *s1, const GUID *s2)
+{
+	s1->Data1 = s2->Data1;
+	s1->Data2 = s2->Data2;
+	s1->Data3 = s2->Data3;
+	memcpy( s1->Data4, s2->Data4, 8);
+
+
+	return (s1);
+}
+
 /* Need to check these */
 #define WAVE_FORMAT_DK3                 0x0061
 #define WAVE_FORMAT_DK4                 0x0062
@@ -256,6 +295,44 @@
         if( wave_format_tag_to_fourcc[i].i_fourcc == fcc ) break;
     }
     if( pi_tag ) *pi_tag = wave_format_tag_to_fourcc[i].i_tag;
+}
+
+/* If wFormatTag is WAVEFORMATEXTENSIBLE, we must look at the SubFormat tag
+ * to determine the actual format.  Microsoft has stopped giving out wFormatTag
+ * assignments in lieu of letting 3rd parties generate their own GUIDs
+ */
+static struct
+{
+    GUID	 			 i_tag;
+    vlc_fourcc_t i_fourcc;
+    char         *psz_name;
+}
+sub_format_tag_to_fourcc[] =
+{ 
+	{ _KSDATAFORMAT_SUBTYPE_PCM_, VLC_FOURCC( 'p', 'c', 'm', ' ' ), "PCM" },
+	{ _KSDATAFORMAT_SUBTYPE_UNKNOWN_, VLC_FOURCC( 'u', 'n', 'd', 'f' ), "Unknown" }
+};
+
+static inline void sf_tag_to_fourcc( GUID *i_tag,
+																		 vlc_fourcc_t *fcc, char **ppsz_name )
+{
+	int i;
+	for( i = 0; guidcmp( &sub_format_tag_to_fourcc[i].i_tag, 
+											 &KSDATAFORMAT_SUBTYPE_UNKNOWN ) != 1; i++ )
+	{
+		if( guidcmp( &sub_format_tag_to_fourcc[i].i_tag, i_tag ) )
+		{
+			break;
+		}
+	}
+	if( fcc )
+	{
+		*fcc = sub_format_tag_to_fourcc[i].i_fourcc;
+	}
+	if( ppsz_name )
+	{
+		*ppsz_name = sub_format_tag_to_fourcc[i].psz_name;
+	}
 }
 
 /**
